==> vradi-swing-0.0.5-sources.jar: com/jurismarches/vradi/ui/admin/nav/AdminClientNavUI.java <==
package com.jurismarches.vradi.ui.admin.nav;

import com.jurismarches.vradi.VradiContext;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.services.dto.*;
import com.jurismarches.vradi.ui.admin.AdminHandler;
import com.jurismarches.vradi.ui.admin.nav.*;
import com.jurismarches.vradi.ui.helpers.AdminNavigationTreeHelper;
import com.jurismarches.vradi.ui.helpers.UIHelper;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.*;
import jaxx.runtime.JAXXBinding;
import jaxx.runtime.JAXXContext;
import jaxx.runtime.JAXXObjectDescriptor;
import jaxx.runtime.swing.*;
import jaxx.runtime.swing.EntityComboBox;
import jaxx.runtime.swing.editor.*;
import static jaxx.runtime.SwingUtil.createImageIcon;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static org.nuiton.i18n.I18n._;
import static org.nuiton.i18n.I18n.n_;

public class AdminClientNavUI extends com.jurismarches.vradi.ui.admin.AdminNavUI {

    /*-----------------------------------------------------------------------*/
    /*------------------------- Other static fields -------------------------*/
    /*-----------------------------------------------------------------------*/

    private static final String $jaxxObjectDescriptor = "H4sIAAAAAAAAAI1TPW8TQRAdH3GCE1BCDFYQQTKJlXINEl0QJBgiYpmAsJAi3GTtW8UbnfeW3TnnoED8BH4C9DRIdFSIgpqCBvEXEKKgRcyuvxJsBFfsnmbmzbyZffP6G2StgUsHPE2ZSRTKjmDVzd3de80D0cJbwraM1Bgb6H2ZAIIGzIVDu0VYbdQcvNyHlytxR8dKqCPo9RrMWnwSCdsWAhEuHke0rC3Xh+71VCdmkHVIalLWlz++By/C568CgFQTO9dK8V+oUSdTNQhkiLBIlbq8HHG1TzSMVPvE97SzVSJu7Q7viMfwDGZqMK25oWQIK//fss/h8alGWGhFkuI2w45UO7z7cBvhaivusIPESNvhptUWlnUNDyVLJOMujCneZR5Q8VgP09rnnEbIl+q+5LaSKHkknwpzGWHNj4EyaxkJw3qs2FjkkTSSWjB4O3VnJVbo+1x0U0iZPaShsOp9rkQ0guRK1ZsJYqyoXv5YYM/swubHo684w9m+08CFYw9GUmAjKYzeKtOArEnIjLDUGFfPA3L1dLP0h25cQu/9Vch/fvf17dZALAHVPjcx9IjW6RG1ibUwKF3p+Z5SEpRR+S7X6w3IWRHRovhFWJ5ArN53Ezmqd8bBmYOzO9y2KUV25sv7D4W9Tycg2ILZKObhFnfx25DDtqEpxFGY6hsbntGpw5N0LjhuCFMoUvdC16SKpBJFjiTdZoLiekpjWJ4whiGXZu7jz3z9zcZgFBmidv6v4aNxZB/BdK+a35z+UkzclDltRRLGI/FPWoeMu/O6r6hlfxbHe3XmFXespom7Sp6y+1vzvgJl+A18ficpyQQAAA==";
    private static final long serialVersionUID = 1L;

    /*-----------------------------------------------------------------------*/
    /*--------------------------- Internal states ---------------------------*/
    /*-----------------------------------------------------------------------*/

    private boolean allComponentsCreated;

    /*-----------------------------------------------------------------------*/
    /*------------------------ Protected components  ------------------------*/
    /*-----------------------------------------------------------------------*/

    protected AdminClientNavUI clientAdminNavUI = this;

    /*-----------------------------------------------------------------------*/
    /*------------------------- Private components  -------------------------*/
    /*-----------------------------------------------------------------------*/

    private javax.swing.JButton $JButton0;
    private javax.swing.JButton $JButton1;

    /*-----------------------------------------------------------------------*/
    /*---------------------- Raw body code from script ----------------------*/
    /*-----------------------------------------------------------------------*/

    // FIXME EC-20100415 hack for hack already present in parent !!!
        protected boolean contextInitialized;
    
        
        public  AdminClientNavUI(JAXXContext parentContext, AdminNavigationTreeHelper helper) {
            super(parentContext, helper);$initialize();
    
            // FIXME EC-20100415 hack for hack already present in parent !!!
            contextInitialized = true;
        $initialize();
    }
    
        public AdminHandler getHandler() {
            return getContextValue(AdminHandler.class);
        }

    /*-----------------------------------------------------------------------*/
    /*--------------------------- Statics methods ---------------------------*/
    /*-----------------------------------------------------------------------*/

    public static JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return JAXXUtil.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*-----------------------------------------------------------------------*/
    /*---------------------------- Constructors  ----------------------------*/
    /*-----------------------------------------------------------------------*/

    public AdminClientNavUI() {
        super();
        $initialize();
    }

    public AdminClientNavUI(JAXXContext parentContext) {
        super(parentContext);
        $initialize();
    }

    /*-----------------------------------------------------------------------*/
    /*---------------------------- Event methods ----------------------------*/
    /*-----------------------------------------------------------------------*/

    public void doActionPerformed__on__$JButton0(java.awt.event.ActionEvent event) {
        getHandler().importClientUsersDBCSV(this);
    }

    public void doActionPerformed__on__$JButton1(java.awt.event.ActionEvent event) {
        getHandler().exportClientUsersDBCSV(this);
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------- Protected acessors methods  ---------------------*/
    /*-----------------------------------------------------------------------*/

    protected javax.swing.JButton get$JButton0() {
        return $JButton0;
    }

    protected javax.swing.JButton get$JButton1() {
        return $JButton1;
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------- Components creation methods ---------------------*/
    /*-----------------------------------------------------------------------*/

    protected void addChildrenToImportExportContent() {
        if (!allComponentsCreated) {
            return;
        }
        importExportContent.add($JButton0);
        importExportContent.add($JButton1);
    }

    @Override
    protected void createImportExportContent() {
        super.createImportExportContent();
        importExportContent.setName("importExportContent");
    }

    /*-----------------------------------------------------------------------*/
    /*------------------------ Internal jaxx methods ------------------------*/
    /*-----------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        addChildrenToImportExportContent();
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        $objectMap.put("clientAdminNavUI", this);
        contextInitialized = false;
        // inline creation of $JButton0
        $objectMap.put("$JButton0", $JButton0 = new javax.swing.JButton());
        $JButton0.setName("$JButton0");
        $JButton0.setText(_("vradi.adminClient.importClientCSV"));
        $JButton0.addActionListener(JAXXUtil.getEventListener(ActionListener.class, "actionPerformed", this, "doActionPerformed__on__$JButton0"));
        // inline creation of $JButton1
        $objectMap.put("$JButton1", $JButton1 = new javax.swing.JButton());
        $JButton1.setName("$JButton1");
        $JButton1.setText(_("vradi.adminClient.exportClientCSV"));
        $JButton1.addActionListener(JAXXUtil.getEventListener(ActionListener.class, "actionPerformed", this, "doActionPerformed__on__$JButton1"));
        // inline creation of clientAdminNavUI
        setName("clientAdminNavUI");
        
        $completeSetup();
    }

}

==> vradi-swing-0.1.0-sources.jar: com/jurismarches/vradi/ui/admin/nav/AdminClientNavUI.java <==
package com.jurismarches.vradi.ui.admin.nav;

import com.jurismarches.vradi.VradiContext;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.ui.admin.AdminHandler;
import com.jurismarches.vradi.ui.admin.helpers.AdminNavigationTreeHelper;
import com.jurismarches.vradi.ui.admin.nav.*;
import com.jurismarches.vradi.ui.helpers.UIHelper;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.*;
import jaxx.runtime.JAXXBinding;
import jaxx.runtime.JAXXContext;
import jaxx.runtime.JAXXObjectDescriptor;
import jaxx.runtime.swing.*;
import jaxx.runtime.swing.EntityComboBox;
import jaxx.runtime.swing.editor.*;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import static jaxx.runtime.SwingUtil.createImageIcon;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static org.nuiton.i18n.I18n._;
import static org.nuiton.i18n.I18n.n_;

public class AdminClientNavUI extends com.jurismarches.vradi.ui.admin.AdminNavUI {

    /*-----------------------------------------------------------------------*/
    /*------------------------- Other static fields -------------------------*/
    /*-----------------------------------------------------------------------*/

    private static final String $jaxxObjectDescriptor = "H4sIAAAAAAAAAI1SPW8TQRAdH7aDkyCcWESJSIRDqNcg0RlBgsEilgkICynCDeu7VbzWfSy7e87RIH4CPwF6GiQ6KkRBTUGD+AsIUdAiZtcfF+NDcMXsaWbezJuZ9/obFJSE7QFNEiLjUPOAkdbe4eG93oC5+hZTruRCRxJGX84BpwtL3tSvNOx02wZeG8NrjSgQUcjCE+h6GxaVfuoz1WdMa9iaRbhK1TrTcD0RsZxUnZLKqvryx3fnhff8lQOQCGSXx1Gq/0Klk+Tb4HBPwyp2GtKaT8MjpCF5eIR8zxhfw6dKHdCAPYFnsNCGoqASi2m4+P8j2xoWnwgNZdfnmLfnBTw8oMOH+xquulFABrHkKqDS7TNFhpJ6nMScUJNGQjokFtCwWAsTwtYsaqhw7C317cTYRhRqS3DV0E+IOsZpSOs+DZmfQkqXWjdjraPwMsJnEkduk7Y8n33FOFbGQQnnZzaNNyTpDdMl57pQkDG6Nax358/+AEOjg6//cXBT0EZ/rVU+v/v6tjm5soO9z2WmnhApbl/ISDCpuWl9dnTiWHO/dpeKehdKivmocKvgzQxinXEYyWG/FQMnBk7uUNXHEoWFL+8/rD3+dAqcJiz6EfWa1OTvQ0n3JW4h8r1E3Ni1jJaPT6MtG24a8pol5kLXeOjzkFWpRs31Ys2uJ7iGzYw1TLn0Sh9/VjpvdieryCG1jb+mp+soPILiqJuV/FjNmRJfEorFXpSqNkvHOfOWxVhRG9Zuzc9q3BeMqSaxebYtZfO3Y2MVrPAbjo9a84IEAAA=";
    private static final Log log = LogFactory.getLog(com.jurismarches.vradi.ui.admin.nav.AdminClientNavUI.class);
    private static final long serialVersionUID = 1L;

    /*-----------------------------------------------------------------------*/
    /*--------------------------- Internal states ---------------------------*/
    /*-----------------------------------------------------------------------*/

    private boolean allComponentsCreated;
    private boolean contextInitialized = true;

    /*-----------------------------------------------------------------------*/
    /*------------------------ Protected components  ------------------------*/
    /*-----------------------------------------------------------------------*/

    protected AdminClientNavUI clientAdminNavUI = this;

    /*-----------------------------------------------------------------------*/
    /*------------------------- Private components  -------------------------*/
    /*-----------------------------------------------------------------------*/

    private javax.swing.JButton $JButton0;
    private javax.swing.JButton $JButton1;

    /*-----------------------------------------------------------------------*/
    /*---------------------- Raw body code from script ----------------------*/
    /*-----------------------------------------------------------------------*/

    // FIXME EC-20100415 hack for hack already present in parent !!! Useless now, keep it if commenting it created some bug
        //protected boolean contextInitialized = false;
        
        public  AdminClientNavUI(JAXXContext parentContext, AdminNavigationTreeHelper helper) {
            super(parentContext, helper);$initialize();
    
            // FIXME EC-20100415 hack for hack already present in parent !!! Useless now, keep it if commenting it created some bug
            //contextInitialized = true;
        $initialize();
    }
    
        public AdminHandler getHandler() {
            return getContextValue(AdminHandler.class);
        }

    /*-----------------------------------------------------------------------*/
    /*--------------------------- Statics methods ---------------------------*/
    /*-----------------------------------------------------------------------*/

    public static JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return JAXXUtil.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*-----------------------------------------------------------------------*/
    /*---------------------------- Constructors  ----------------------------*/
    /*-----------------------------------------------------------------------*/

    public AdminClientNavUI() {
        super();
        $initialize();
    }

    public AdminClientNavUI(JAXXContext parentContext) {
        super(parentContext);
        $initialize();
    }

    /*-----------------------------------------------------------------------*/
    /*---------------------------- Event methods ----------------------------*/
    /*-----------------------------------------------------------------------*/

    public void doActionPerformed__on__$JButton0(java.awt.event.ActionEvent event) {
        getHandler().importClientUsersDBCSV(this);
    }

    public void doActionPerformed__on__$JButton1(java.awt.event.ActionEvent event) {
        getHandler().exportClientUsersDBCSV(this);
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------- Protected acessors methods  ---------------------*/
    /*-----------------------------------------------------------------------*/

    protected javax.swing.JButton get$JButton0() {
        return $JButton0;
    }

    protected javax.swing.JButton get$JButton1() {
        return $JButton1;
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------- Components creation methods ---------------------*/
    /*-----------------------------------------------------------------------*/

    protected void addChildrenToImportExportContent() {
        if (!allComponentsCreated) {
            return;
        }
        importExportContent.add($JButton0);
        importExportContent.add($JButton1);
    }

    @Override
    protected void createImportExportContent() {
        super.createImportExportContent();
        importExportContent.setName("importExportContent");
    }

    /*-----------------------------------------------------------------------*/
    /*------------------------ Internal jaxx methods ------------------------*/
    /*-----------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        addChildrenToImportExportContent();
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        $objectMap.put("clientAdminNavUI", this);
        // inline creation of $JButton0
        $objectMap.put("$JButton0", $JButton0 = new javax.swing.JButton());
        
        $JButton0.setName("$JButton0");
        $JButton0.setText(_("vradi.adminClient.importClientCSV"));
        $JButton0.addActionListener(JAXXUtil.getEventListener(ActionListener.class, "actionPerformed", this, "doActionPerformed__on__$JButton0"));
        // inline creation of $JButton1
        $objectMap.put("$JButton1", $JButton1 = new javax.swing.JButton());
        
        $JButton1.setName("$JButton1");
        $JButton1.setText(_("vradi.adminClient.exportClientCSV"));
        $JButton1.addActionListener(JAXXUtil.getEventListener(ActionListener.class, "actionPerformed", this, "doActionPerformed__on__$JButton1"));
        // inline creation of clientAdminNavUI
        setName("clientAdminNavUI");
        
        $completeSetup();
    }

}
